@@ -4,9 +4,10 @@
 #include "core/float_types.h"
 #include "core/int_types.h"
 #include "core/mem.h"
+#include "core/platform.h"
+#include "core/slice.h"
 #include "std/alloc.h"
 #include "std/audio.h"
-#include "std/collections/slice.h"
 #include "std/collections/vec.h"
 #include "std/def.h"
 #include "std/env.h"
